# 超星学习通 deadline 汇总，目前仅适用于上海大学

## 环境
python版本：3.6+

## 使用方法
- Windows

### 安装
```bash
pip install ohmyddl
```

### 运行
```bash
ohmyddl.exe
```
如果浏览器窗口没有自动打开，可在地址栏输入：http://localhost:5986/

### 命令行（可选）
```bash
ohmyddl-cli.exe -h
```

### 移除
```bash
pip uninstall ohmyddl
```

- Linux

### 安装
```bash
pip3 install ohmyddl --user
```
### 运行
```bash
# 正常运行（web）
# 如果浏览器窗口没有自动打开，可在地址栏输入：http://localhost:5986/
ohmyddl

# 命令行
ohmyddl-cli -h
```

### 移除
```bash
pip3 uninstall ohmyddl
```

## 反馈

- 邮箱： github@qiren.org
